@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 # Copyright (C) 2011 Rocky Bernstein <rocky@cpan.org>
 use warnings; no warnings 'redefine';
-use feature 'switch';
 use rlib '../../../..';
 
 use Devel::Trepan::DB::LineCache;
@@ -124,6 +123,13 @@ sub run($$) {
 	    my $line_num = $bp->line_num;
 	    $proc->{brkpts}->add($bp);
 	    $proc->msg("$prefix $id set in $filename at line $line_num");
+	    # Warn if we are setting a breakpoint on a line that starts
+	    # "use.."
+	    my $text = DB::LineCache::getline($bp->filename, $line_num, 
+					      {output => 'plain'});
+	    if (defined($text) && $text =~ /^\s*use\s+/) {
+		$proc->msg("Warning: 'use' statements get evaluated at compile time... You may have already passed this statement.");
+	    }
     }
 }
 
