@@ -1,6 +1,11 @@
+# -*- coding: utf-8 -*-
+# Copyright (C) 2011 Rocky Bernstein <rocky@cpan.org>
+use warnings;  
+# FIXME: Can't use strict;
 use rlib '../..';
 use Devel::Trepan::DB;
 use Devel::Trepan::CmdProcessor;
+use Devel::Trepan::SigHandler;
 use Devel::Trepan::WatchMgr;
 use Devel::Trepan::IO::Output;
 use Devel::Trepan::Interface::Script;
@@ -24,15 +29,14 @@ sub add_startup_files($$) {
 
 sub new {
     my $class = shift;
+    my %ORIG_SIG = %SIG; # Makes a copy of %SIG;
     my $self = {
-	watch => Devel::Trepan::WatchMgr->new(), # List of watch expressions
+	watch  => Devel::Trepan::WatchMgr->new(), # List of watch expressions
+	orig_sig => \%ORIG_SIG,
+	caught_signal => 0
     };
     bless $self, $class;
-}
-
-# Called by DB to initialize us.
-sub init() {
-    print "init called\n";
+    return $self;
 }
 
 # Called when debugger is ready for reading commands. Main
@@ -42,12 +46,31 @@ sub idle($$$)
     my ($self, $event, $args) = @_;
     my $proc = $self->{proc};
     $proc->process_commands($DB::caller, $event, $args);
+    $self->{caught_signal} = 0;
+}
+
+# Called on catching a signal that SigHandler says
+# we should enter the debugger for. That it there is 'stop'
+# set on that signal.
+sub signal_handler($$$)
+{
+    my ($self, $signame) = @_;
+    $DB::running = 0;
+    $DB::step    = 0;
+    $DB::caller = [caller(1)];
+    ($DB::package, $DB::filename, $DB::lineno, $DB::subroutine, $DB::hasargs,
+     $DB::wantarray, $DB::evaltext, $DB::is_require, $DB::hints, $DB::bitmask,
+     $DB::hinthash
+    ) = @{$DB::caller};
+    my $proc = $self->{proc};
+    $self->{caught_signal} = 1;
+    $DB::signal = 2;
 }
 
 sub output($) 
 {
     my ($self, $msg) = @_;
-    $proc = $self->{proc};
+    my $proc = $self->{proc};
     chomp($msg);
     $proc->msg($msg);
 }
@@ -55,7 +78,7 @@ sub output($)
 sub warning($) 
 {
     my ($self, $msg) = @_;
-    $proc = $self->{proc};
+    my $proc = $self->{proc};
     chomp($msg);
     $proc->errmsg($msg);
 }
@@ -67,13 +90,19 @@ sub awaken($;$) {
     if (!defined($opts) && $ENV{'TREPANPL_OPTS'}) {
 	$opts = eval "$ENV{'TREPANPL_OPTS'}";
     }
+
+    $SIG{__DIE__}  = \&DB::catch if $opts->{post_mortem};
+
     my %cmdproc_opts = ();
-    for my $field (qw(basename highlight readline traceprint)) {
+    for my $field (qw(basename cmddir highlight readline traceprint)) {
 	# print "field $field $opts->{$field}\n";
 	$cmdproc_opts{$field} = $opts->{$field};
     }
+    my $cmdproc;
 
-    if (my $batch_filename = $opts->{testing} // $opts->{batchfile}) {
+    my $batch_filename = $opts->{testing};
+    $batch_filename = $opts->{batchfile} unless defined $batch_filename;
+    if (defined $batch_filename) {
 	my $result = Devel::Trepan::Util::invalid_filename($batch_filename);
 	if (defined $result) {
 	    print STDERR "$result\n" 
@@ -85,16 +114,16 @@ sub awaken($;$) {
 		Devel::Trepan::Interface::Script->new($batch_filename, 
 						      $output, 
 						      $script_opts);
-	    my $cmdproc = Devel::Trepan::CmdProcessor->new([$script_intf], 
-							   $self, 
-							   \%cmdproc_opts);
+	    $cmdproc = Devel::Trepan::CmdProcessor->new([$script_intf], 
+							$self, 
+							\%cmdproc_opts);
 	    $self->{proc} = $cmdproc;
 	    $main::TREPAN_CMDPROC = $self->{proc};
         }
     } else {
 	my $intf = undef;
 	if ($opts->{server}) {
-	    $server_opts = {
+	    my $server_opts = {
 		host   => $opts->{host},
 		port   => $opts->{port},
 		logger => *STDOUT
@@ -104,12 +133,12 @@ sub awaken($;$) {
 						      $server_opts)
 		];
 	}
-	my $cmdproc = Devel::Trepan::CmdProcessor->new($intf, $self, 
-						       \%cmdproc_opts);
+	$cmdproc = Devel::Trepan::CmdProcessor->new($intf, $self, 
+						    \%cmdproc_opts);
 	$self->{proc} = $cmdproc;
 	$main::TREPAN_CMDPROC = $self->{proc};
-	$opts //= {};
-	
+	$opts = {} unless defined $opts;
+
 	for my $startup_file (@{$opts->{cmdfiles}}) {
 	    add_startup_files($cmdproc, $startup_file);
 	}
@@ -117,6 +146,12 @@ sub awaken($;$) {
 	    add_startup_files($cmdproc, $opts->{initfile});
 	}
     }
+    $self->{sigmgr} = 
+	Devel::Trepan::SigMgr->new(sub{ $DB::running = 0; $DB::single = 0;
+					$self->signal_handler(@_) },
+				   sub {$cmdproc->msg(@_)},
+				   sub {$cmdproc->errmsg(@_)},
+				   sub {$cmdproc->section(@_)});
 }
 
 sub display_lists ($)
@@ -124,7 +159,9 @@ sub display_lists ($)
     my $self = shift;
     return $self->{proc}{displays}{list};
 }
-    
+
+# FIXME: should probably remove the next line and put the 
+# below inside new, and adjust DB.
 $dbgr = __PACKAGE__->new();
 $dbgr->awaken();
 $dbgr->register();
